/* OthelloDigits.java */

import java.applet.*;
import java.awt.*;

/** OthelloDigits. */
public class OthelloDigits
{
	/** Characters on images, in order. */
	private String chars="0123456789 -AIYOUH";
	/** Character image filenames, without prefix and suffix. */
	private String [] filename={"0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "off", "hyphen", "a", "1", "y", "0", "u", "h"};
	/** Character images. */
	private Image [] pic;
	/** Applet from which to read images, and use as ImageObserver. */
	private Applet a;
	
	/** Creates an OthelloDigits object.
	    The constructor needs an Applet to read images from, and to use as ImageObserver when drawing. */
	public OthelloDigits(Applet applet)
	{
		a=applet;
		pic=new Image[filename.length];
		MediaTracker mt=new MediaTracker(a);
		for(int i=0;i<filename.length;i++)
		{
			pic[i]=a.getImage(a.getCodeBase(), "pix/d"+filename[i]+".gif");
			mt.addImage(pic[i], i);
		}
        try{mt.waitForAll();}
        catch(InterruptedException e){};
	}
	
	/** Draws a digit on the Graphics object.
	    If the input number is less than 0, the blank character is drawn.
	    If the input number is larger than 9, only the last digit is used. */
	public void drawDigit(int digit, Graphics g, int x, int y)
	{
		int index=digit%10;
		if(index<0)
			index=chars.indexOf(' ');
		g.drawImage(pic[index], x, y, a);
	}
	
	/** Draws a character on the Graphics object.
	    If the character does not have a corresponding image, the blank character is drawn. */
	public void drawDigit(char digit, Graphics g, int x, int y)
	{
		int index=chars.indexOf(digit);
		if(index<0)
			index=chars.indexOf(' ');
		g.drawImage(pic[index], x, y, a);
	}
	
	/** Draws a String on the Graphics object.
	    Characters that don't have corresponding images are replaced by the blank (space) character. */
	public void drawString(String s, Graphics g, int x, int y)
	{
		for(int i=0;i<s.length();i++)
			drawDigit(s.charAt(i), g, x+i*16, y);
	}
	
	/** Draws a two-digit positive number on the Graphics object.
	    If the number is negative, two blank characters are drawn.
	    If the number is larger than 99, only the two last digits are used. */
	public void drawNumber(int number, Graphics g, int x, int y)
	{
		int high=((number/10)%10);
		drawDigit(high>0?high:-1, g, x, y);
		drawDigit((number%10), g, x+16, y);
	}
}
